@@ -43,7 +43,10 @@ public final class Settings {
 
     public static final String OUTLOOK_URL = "https://outlook.office365.com";
     public static final String O365_URL = OUTLOOK_URL+"/EWS/Exchange.asmx";
-    public static final String O365_LOGIN_URL = "https://login.microsoftonline.com/";
+
+    public static final String GRAPH_URL = "https://graph.microsoft.com";
+
+    public static final String O365_LOGIN_URL = "https://login.microsoftonline.com";
 
     public static final String O365 = "O365";
     public static final String O365_MODERN = "O365Modern";
@@ -145,7 +148,7 @@ public final class Settings {
      */
     public static void setDefaultSettings() {
         SETTINGS_PROPERTIES.put("davmail.mode", "EWS");
-        SETTINGS_PROPERTIES.put("davmail.url", O365_URL);
+        SETTINGS_PROPERTIES.put("davmail.url", getO365Url());
         SETTINGS_PROPERTIES.put("davmail.popPort", "1110");
         SETTINGS_PROPERTIES.put("davmail.imapPort", "1143");
         SETTINGS_PROPERTIES.put("davmail.smtpPort", "1025");
@@ -740,9 +743,24 @@ public final class Settings {
         return getProperty("davmail.userAgent", Settings.EDGE_USER_AGENT);
     }
 
+    public static String getOutlookUrl() {
+        String tld = getProperty("davmail.tld");
+        String outlookUrl = getProperty("davmail.outlookUrl");
+        if (outlookUrl != null) {
+            return outlookUrl;
+        } else if (tld == null) {
+            return OUTLOOK_URL;
+        } else {
+            return  "https://outlook.office365."+tld;
+        }
+    }
+
     public static String getO365Url() {
         String tld = getProperty("davmail.tld");
-        if (tld == null) {
+        String outlookUrl = getProperty("davmail.outlookUrl");
+        if (outlookUrl != null) {
+            return outlookUrl+"/EWS/Exchange.asmx";
+        } else if (tld == null) {
             return O365_URL;
         } else {
             return  "https://outlook.office365."+tld+"/EWS/Exchange.asmx";
@@ -751,10 +769,13 @@ public final class Settings {
 
     public static String getO365LoginUrl() {
         String tld = getProperty("davmail.tld");
-        if (tld == null) {
+        String loginUrl = getProperty("davmail.loginUrl");
+        if (loginUrl != null) {
+            return loginUrl;
+        } else if (tld == null) {
             return O365_LOGIN_URL;
         } else {
-            return  "https://login.microsoftonline."+tld+"/";
+            return  "https://login.microsoftonline."+tld;
         }
     }
 }
