@@ -19,6 +19,7 @@
 
 package davmail.exchange.auth;
 
+import davmail.BundleMessage;
 import davmail.Settings;
 import davmail.exception.DavMailAuthenticationException;
 import davmail.http.HttpClientAdapter;
@@ -27,6 +28,7 @@ import davmail.http.request.PostRequest;
 import davmail.http.request.ResponseWrapper;
 import davmail.http.request.RestRequest;
 import davmail.ui.NumberMatchingFrame;
+import davmail.ui.PasswordPromptDialog;
 import org.apache.http.HttpStatus;
 import org.apache.http.client.utils.URIBuilder;
 import org.apache.log4j.Logger;
@@ -35,7 +37,9 @@ import org.codehaus.jettison.json.JSONObject;
 
 import javax.swing.*;
 import java.awt.*;
+import java.io.BufferedReader;
 import java.io.IOException;
+import java.io.InputStreamReader;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.util.regex.Matcher;
@@ -55,9 +59,7 @@ public class O365Authenticator implements ExchangeAuthenticator {
     public static String buildAuthorizeUrl(String tenantId, String clientId, String redirectUri, String username) throws IOException {
         URI uri;
         try {
-            URIBuilder uriBuilder = new URIBuilder()
-                    .setScheme("https")
-                    .setHost("login.microsoftonline.com")
+            URIBuilder uriBuilder = new URIBuilder(Settings.getO365LoginUrl())
                     .addParameter("client_id", clientId)
                     .addParameter("response_type", "code")
                     .addParameter("redirect_uri", redirectUri)
@@ -65,14 +67,21 @@ public class O365Authenticator implements ExchangeAuthenticator {
                     .addParameter("login_hint", username);
 
             // force consent
-            //uriBuilder.addParameter("prompt", "consent")
+            //uriBuilder.addParameter("prompt", "consent");
             // switch to new v2.0 OIDC compliant endpoint https://docs.microsoft.com/en-us/azure/active-directory/develop/azure-ad-endpoint-comparison
             if (Settings.getBooleanProperty("davmail.enableOidc", false)) {
                 uriBuilder.setPath("/" + tenantId + "/oauth2/v2.0/authorize")
-                        .addParameter("scope", "openid " + Settings.OUTLOOK_URL + "/EWS.AccessAsUser.All");
+                        .addParameter("scope", "openid " + Settings.getOutlookUrl() + "/EWS.AccessAsUser.All");
+            } else if (Settings.getBooleanProperty("davmail.enableGraph", false)) {
+                uriBuilder.setPath("/" + tenantId + "/oauth2/authorize")
+                        .addParameter("resource", "https://graph.microsoft.com");
+                // OIDC compliant
+                //uriBuilder.setPath("/" + tenantId + "/oauth2/v2.0/authorize")
+                //        .addParameter("scope", "Mail.ReadWrite Calendars.ReadWrite MailboxSettings.Read");
+                        //.addParameter("scope", "openid " + Settings.getOutlookUrl() + "/EWS.AccessAsUser.All AuditLog.Read.All Calendar.ReadWrite Calendars.Read.Shared Calendars.ReadWrite Contacts.ReadWrite DataLossPreventionPolicy.Evaluate Directory.AccessAsUser.All Directory.Read.All Files.Read Files.Read.All Files.ReadWrite.All Group.Read.All Group.ReadWrite.All InformationProtectionPolicy.Read Mail.ReadWrite Mail.Send Notes.Create Organization.Read.All People.Read People.Read.All Printer.Read.All PrintJob.ReadWriteBasic SensitiveInfoType.Detect SensitiveInfoType.Read.All SensitivityLabel.Evaluate Tasks.ReadWrite TeamMember.ReadWrite.All TeamsTab.ReadWriteForChat User.Read.All User.ReadBasic.All User.ReadWrite Users.Read");
             } else {
                 uriBuilder.setPath("/" + tenantId + "/oauth2/authorize")
-                        .addParameter("resource", Settings.OUTLOOK_URL);
+                        .addParameter("resource", Settings.getOutlookUrl());
             }
 
             uri = uriBuilder.build();
@@ -101,7 +110,7 @@ public class O365Authenticator implements ExchangeAuthenticator {
     }
 
     public URI getExchangeUri() {
-        return URI.create(Settings.O365_URL);
+        return URI.create(Settings.getO365Url());
     }
 
     /**
@@ -118,7 +127,7 @@ public class O365Authenticator implements ExchangeAuthenticator {
         // common DavMail client id
         String clientId = Settings.getProperty("davmail.oauth.clientId", "facd6cff-a294-4415-b59f-c5b01937d7bd");
         // standard native app redirectUri
-        String redirectUri = Settings.getProperty("davmail.oauth.redirectUri", Settings.O365_LOGIN_URL+"common/oauth2/nativeclient");
+        String redirectUri = Settings.getProperty("davmail.oauth.redirectUri", Settings.getO365LoginUrl()+"/common/oauth2/nativeclient");
         // company tenantId or common
         tenantId = Settings.getProperty("davmail.oauth.tenantId", "common");
 
@@ -154,7 +163,7 @@ public class O365Authenticator implements ExchangeAuthenticator {
 
                 String referer = getRequest.getURI().toString();
 
-                RestRequest getCredentialMethod = new RestRequest(Settings.getO365LoginUrl() + tenantId + "/GetCredentialType");
+                RestRequest getCredentialMethod = new RestRequest(Settings.getO365LoginUrl()  + "/" + tenantId + "/GetCredentialType");
                 getCredentialMethod.setRequestHeader("Accept", "application/json");
                 getCredentialMethod.setRequestHeader("canary", apiCanary);
                 getCredentialMethod.setRequestHeader("client-request-id", clientRequestId);
@@ -186,7 +195,7 @@ public class O365Authenticator implements ExchangeAuthenticator {
                     LOGGER.debug("Detected ADFS, redirecting to " + federationRedirectUrl);
                     code = authenticateRedirectADFS(httpClientAdapter, federationRedirectUrl, url);
                 } else {
-                    PostRequest logonMethod = new PostRequest(Settings.getO365LoginUrl() + tenantId + "/login");
+                    PostRequest logonMethod = new PostRequest(Settings.getO365LoginUrl()  + "/" + tenantId + "/login");
                     logonMethod.setRequestHeader("Accept", "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8");
                     logonMethod.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
 
@@ -214,17 +223,23 @@ public class O365Authenticator implements ExchangeAuthenticator {
                             LOGGER.warn("Authentication successful but user consent or validation needed, please open the following url in a browser");
                             LOGGER.warn(url);
                             throw new DavMailAuthenticationException("EXCEPTION_AUTHENTICATION_FAILED");
+                        } else if ("50126".equals(config.optString("sErrorCode"))) {
+                            throw new DavMailAuthenticationException("EXCEPTION_AUTHENTICATION_FAILED");
+                        } else if ("50125".equals(config.optString("sErrorCode"))) {
+                            throw new DavMailAuthenticationException("LOG_MESSAGE", "Your organization needs more information to keep your account secure, authenticate once in a web browser and try again");
                         } else if (config.optString("strServiceExceptionMessage") != null) {
                             LOGGER.debug("O365 returned error: " + config.optString("strServiceExceptionMessage"));
                             throw new DavMailAuthenticationException("EXCEPTION_AUTHENTICATION_FAILED");
-                        } else if ("50126".equals(config.optString("sErrorCode"))) {
-                            throw new DavMailAuthenticationException("EXCEPTION_AUTHENTICATION_FAILED");
                         } else {
                             throw new DavMailAuthenticationException("LOG_MESSAGE", "Authentication failed, unknown error: " + config);
                         }
                     }
                     String query = location.toString();
-                    code = query.substring(query.indexOf("code=") + 5, query.indexOf("&session_state="));
+                    if (query.contains("code=")) {
+                        code = query.substring(query.indexOf("code=") + 5, query.indexOf("&session_state="));
+                    } else {
+                        throw new DavMailAuthenticationException("LOG_MESSAGE", "Authentication failed, unknown error: " + query);
+                    }
                 }
             }
             LOGGER.debug("Authentication Code: " + code);
@@ -253,7 +268,7 @@ public class O365Authenticator implements ExchangeAuthenticator {
     private String authenticateADFS(HttpClientAdapter httpClientAdapter, String responseBodyAsString, String authorizeUrl) throws IOException, JSONException {
         URI location;
 
-        if (responseBodyAsString.contains("login.microsoftonline.com")) {
+        if (responseBodyAsString.contains(Settings.getO365LoginUrl())) {
             LOGGER.info("Already authenticated through Basic or NTLM");
         } else {
             // parse form to get target url, authenticate as userid
@@ -274,7 +289,7 @@ public class O365Authenticator implements ExchangeAuthenticator {
             responseBodyAsString = httpClientAdapter.executeGetRequest(redirectMethod);
         }
 
-        if (!responseBodyAsString.contains("login.microsoftonline.com")) {
+        if (!responseBodyAsString.contains(Settings.getO365LoginUrl())) {
             throw new DavMailAuthenticationException("EXCEPTION_AUTHENTICATION_FAILED");
         }
         String targetUrl = extract("action=\"([^\"]+)\"", responseBodyAsString);
@@ -311,7 +326,7 @@ public class O365Authenticator implements ExchangeAuthenticator {
             throw new IOException("Unknown ADFS authentication failure");
         }
 
-        if ("device.login.microsoftonline.com".equals(location.getHost())) {
+        if (location.getHost().startsWith("device")) {
             location = processDeviceLogin(httpClientAdapter, location);
         }
         String query = location.getQuery();
@@ -341,7 +356,7 @@ public class O365Authenticator implements ExchangeAuthenticator {
 
         String responseBodyAsString = httpClient.executeGetRequest(deviceLoginMethod);
 
-        if (responseBodyAsString.contains("login.microsoftonline.com")) {
+        if (responseBodyAsString.contains(Settings.getO365LoginUrl())) {
             String ctx = extract("name=\"ctx\" value=\"([^\"]+)\"", responseBodyAsString);
             String flowtoken = extract("name=\"flowtoken\" value=\"([^\"]+)\"", responseBodyAsString);
 
@@ -374,16 +389,29 @@ public class O365Authenticator implements ExchangeAuthenticator {
         String urlBeginAuth = config.getString("urlBeginAuth");
         String urlEndAuth = config.getString("urlEndAuth");
         // Get processAuth url from config
-        String urlProcessAuth = config.optString("urlPost", Settings.getO365LoginUrl() + tenantId + "/SAS/ProcessAuth");
+        String urlProcessAuth = config.optString("urlPost", Settings.getO365LoginUrl()  + "/" + tenantId + "/SAS/ProcessAuth");
 
         boolean isMFAMethodSupported = false;
+        String chosenAuthMethodId = null;
+        String chosenAuthMethodPrompt = null;
 
         for (int i = 0; i < config.getJSONArray("arrUserProofs").length(); i++) {
             JSONObject authMethod = (JSONObject) config.getJSONArray("arrUserProofs").get(i);
-            LOGGER.debug("Authentication method: " + authMethod.getString("authMethodId"));
-            if ("PhoneAppNotification".equals(authMethod.getString("authMethodId"))) {
+            String authMethodId = authMethod.getString("authMethodId");
+            LOGGER.debug("Authentication method: " + authMethodId);
+            if ("PhoneAppNotification".equals(authMethodId)) {
                 LOGGER.debug("Found phone app auth method " + authMethod.getString("display"));
                 isMFAMethodSupported = true;
+                chosenAuthMethodId = authMethodId;
+                chosenAuthMethodPrompt = authMethod.getString("display");
+                // prefer phone app
+                break;
+            }
+            if ("OneWaySMS".equals(authMethodId)) {
+                LOGGER.debug("Found OneWaySMS auth method " + authMethod.getString("display"));
+                chosenAuthMethodId = authMethodId;
+                chosenAuthMethodPrompt = authMethod.getString("display");
+                isMFAMethodSupported = true;
             }
         }
 
@@ -417,7 +445,7 @@ public class O365Authenticator implements ExchangeAuthenticator {
 
         // only support PhoneAppNotification
         JSONObject beginAuthJson = new JSONObject();
-        beginAuthJson.put("AuthMethodId", "PhoneAppNotification");
+        beginAuthJson.put("AuthMethodId", chosenAuthMethodId);
         beginAuthJson.put("Ctx", context);
         beginAuthJson.put("FlowToken", flowToken);
         beginAuthJson.put("Method", "BeginAuth");
@@ -435,13 +463,15 @@ public class O365Authenticator implements ExchangeAuthenticator {
 
         // display number matching value to user
         NumberMatchingFrame numberMatchingFrame = null;
-        if (entropy != null) {
+        if (entropy != null && !"0".equals(entropy)) {
             LOGGER.info("Number matching value for " + username + ": " + entropy);
             if (!Settings.getBooleanProperty("davmail.server") && !GraphicsEnvironment.isHeadless()) {
                 numberMatchingFrame = new NumberMatchingFrame(entropy);
             }
         }
 
+        String smsCode = retrieveSmsCode(chosenAuthMethodId, chosenAuthMethodPrompt);
+
         context = config.getString("Ctx");
         flowToken = config.getString("FlowToken");
         String sessionId = config.getString("SessionId");
@@ -467,13 +497,17 @@ public class O365Authenticator implements ExchangeAuthenticator {
                 endAuthMethod.setRequestHeader("hpgrequestid", hpgrequestid);
 
                 JSONObject endAuthJson = new JSONObject();
-                endAuthJson.put("AuthMethodId", "PhoneAppNotification");
+                endAuthJson.put("AuthMethodId", chosenAuthMethodId);
                 endAuthJson.put("Ctx", context);
                 endAuthJson.put("FlowToken", flowToken);
                 endAuthJson.put("Method", "EndAuth");
                 endAuthJson.put("PollCount", "1");
                 endAuthJson.put("SessionId", sessionId);
 
+                // When in beginAuthMethod is used 'AuthMethodId': 'OneWaySMS', then in endAuthMethod is send SMS code
+                // via attribute 'AdditionalAuthData'
+                endAuthJson.put("AdditionalAuthData", smsCode);
+
                 endAuthMethod.setJsonBody(endAuthJson);
 
                 config = httpClientAdapter.executeRestRequest(endAuthMethod);
@@ -482,6 +516,9 @@ public class O365Authenticator implements ExchangeAuthenticator {
                 if ("PhoneAppDenied".equals(resultValue) || "PhoneAppNoResponse".equals(resultValue)) {
                     throw new DavMailAuthenticationException("EXCEPTION_AUTHENTICATION_FAILED_REASON", resultValue);
                 }
+                if ("SMSAuthFailedWrongCodeEntered".equals(resultValue)) {
+                    smsCode = retrieveSmsCode(chosenAuthMethodId, chosenAuthMethodPrompt);
+                }
                 if (config.getBoolean("Success")) {
                     success = true;
                 }
@@ -523,6 +560,23 @@ public class O365Authenticator implements ExchangeAuthenticator {
 
     }
 
+    private String retrieveSmsCode(String chosenAuthMethodId, String chosenAuthMethodPrompt) throws IOException {
+        String smsCode = null;
+        if ("OneWaySMS".equals(chosenAuthMethodId)) {
+            LOGGER.info("Need to retrieve SMS verification code for " + username);
+            if (Settings.getBooleanProperty("davmail.server") || GraphicsEnvironment.isHeadless()) {
+                // headless or server mode
+                System.out.print(BundleMessage.format("UI_SMS_PHONE_CODE", chosenAuthMethodPrompt));
+                BufferedReader inReader = new BufferedReader(new InputStreamReader(System.in));
+                smsCode = inReader.readLine();
+            } else {
+                PasswordPromptDialog passwordPromptDialog = new PasswordPromptDialog(BundleMessage.format("UI_SMS_PHONE_CODE", chosenAuthMethodPrompt));
+                smsCode = String.valueOf(passwordPromptDialog.getPassword());
+            }
+        }
+        return smsCode;
+    }
+
     private String executeFollowRedirect(HttpClientAdapter httpClientAdapter, GetRequest getRequest) throws IOException {
         LOGGER.debug(getRequest.getURI());
         ResponseWrapper responseWrapper = httpClientAdapter.executeFollowRedirect(getRequest);
