@@ -443,6 +443,76 @@ public final class StringUtil {
         return result;
     }
 
+    /**
+     * Takes a quoted string according to IMAP rfc 3501 and returns its intrinsic (unquoted) string value.
+     *
+     * <p>RFC 3501 defines a quoted string in its ABNF as follows:</p>
+     * <pre>
+     *     quoted          = DQUOTE *QUOTED-CHAR DQUOTE
+     *     DQUOTE          = %x22
+     *                       ; " (Double Quote)
+     *     QUOTED-CHAR     = &lt;any TEXT-CHAR except quoted-specials&gt; /
+     *                       "\" quoted-specials / UTF8-2 / UTF8-3 / UTF8-4
+     *     TEXT-CHAR       = &lt;any CHAR except CR and LF&gt;
+     *     quoted-specials = DQUOTE / "\"
+     * </pre>
+     *
+     * @param quoted the quoted string or null
+     * @return the unquoted string, or null if-and-only-if `quoted` was null
+     * @throws IllegalArgumentException when the given quoted string is not valid
+     */
+    public static String parseQuotedImapString(String quoted) throws ParseException {
+        if (null == quoted) {
+            return null;
+        }
+        char[] quotedChars = quoted.toCharArray();
+        if (quotedChars.length < 2) {
+            // not a quoted string. even the empty string is, in it's quoted form, represented as: "\"\""
+            // (two double quotes)
+            throw new ParseException("Not a valid imap quoted string (too short): " + quoted, 0);
+        }
+        if ('"' != quotedChars[0]) {
+            throw new ParseException("Not a valid imap quoted string (does not start with double quote): " + quoted, 0);
+        }
+        // the result length is at least by 2 chars shorter than the input length, as at least the two enclosing
+        // double quotes are removed.
+        char[] resultChars = new char[quotedChars.length - 2];
+
+        // 0 is the index of the first char in resultChars that is the actual result
+        // resultPos is the index of the last byte in resultChars that is the actual result
+        // resultChars MAY have additional bytes (when resultPos + 1 < resultChars.length), that are not part of the result.
+        int resultPos = 0;
+        // a very mechanical approach, looking at one character at a time
+        boolean backslashMode = false;
+        // iterate ignoring starting and ending quotes
+        for (int i = 1; i < quotedChars.length - 1; i++) {
+            if (backslashMode) {
+                if ('\\' == quotedChars[i] || '"' == quotedChars[i]) {
+                    resultChars[resultPos++] = quotedChars[i];
+                    backslashMode = false;
+                } else {
+                    throw new ParseException("Not a valid imap quoted string "
+                            + "(only '\"' and '\\' allowed after '\\') at index " + i + ": " + quoted, i);
+                }
+            } else {
+                if ('\\' == quotedChars[i]) {
+                    backslashMode = true;
+                } else {
+                    resultChars[resultPos++] = quotedChars[i];
+                }
+            }
+        }
+        if (backslashMode) {
+            throw new ParseException("Not a valid imap quoted string "
+                    + "(outer ending quote is backslashed): " + quoted, quotedChars.length - 1);
+        }
+        if ('"' != quotedChars[quotedChars.length - 1]) {
+            throw new ParseException("Not a valid imap quoted string "
+                    + "(does not end with double quotes): " + quoted, quotedChars.length - 1);
+        }
+        return new String(resultChars, 0, resultPos);
+    }
+
     /**
      * Remove quotes if present on value.
      *
